@@ -15,17 +15,24 @@
         with dist_lock('test', client):
             print 'Is there anybody out there!?'
 
+    :copyright: 2010 by amix the lucky stiff.
+    :license: BSD
 """
 
 from __future__ import with_statement
-from contextlib import contextmanager
+
 import time
 
+from contextlib import contextmanager
+from random import random
+
 DEFAULT_EXPIRES = 15
 DEFAULT_RETRIES = 5
 
 @contextmanager
 def dist_lock(key, client):
+    key = '__d_lock_%s' % key
+
     try:
         _acquire_lock(key, client)
         yield
@@ -37,8 +44,9 @@ def _acquire_lock(key, client):
         stored = client.add(key, 1, DEFAULT_EXPIRES)
         if stored:
             return
-        print 'Sleeipng for %s' % ((2**i) / 3.5)
-        time.sleep((2**i) / 2.5)
+        sleep_time = (((i+1)*random()) + 2**i) / 2.5
+        print 'Sleeipng for %s' % (sleep_time)
+        time.sleep(sleep_time)
     raise Exception('Could not acquire lock for %s' % key)
 
 def _release_lock(key, client):
